@@ -98,6 +98,7 @@ class TQSL_CONVERTER {
 	bool need_ident_rec;
 	char *appName;
 	int dxcc;
+	bool newstation;
 };
 
 #if !defined(__APPLE__) && !defined(_WIN32) && !defined(__clang__)
@@ -1140,6 +1141,7 @@ static void parse_adif_qso(TQSL_CONVERTER *conv, int *saveErr, TQSL_ADIF_GET_FIE
 		}
 
 		if (!strcasecmp(result.name, "CALL") && resdata) {
+			tqsl_strtoupper(resdata);
 			conv->rec.callsign_set = true;
 			strncpy(conv->rec.callsign, resdata, sizeof conv->rec.callsign);
 		} else if (!strcasecmp(result.name, "BAND") && resdata) {
@@ -1179,7 +1181,7 @@ static void parse_adif_qso(TQSL_CONVERTER *conv, int *saveErr, TQSL_ADIF_GET_FIE
 			char *p = strstr(resdata, ",");			// Find the comma in "VA,Fairfax"
 			if (p) {
 				*p++ = '\0';
-				strncpy(conv->rec.my_cnty_state, resdata, sizeof conv->rec.my_cnty_state); 
+				strncpy(conv->rec.my_cnty_state, resdata, sizeof conv->rec.my_cnty_state);
 				while (isspace(*p)) p++;		// Skip spaces and comma
 				strncpy(conv->rec.my_county, p, sizeof conv->rec.my_county);
 			} else {
@@ -1215,6 +1217,7 @@ static void parse_adif_qso(TQSL_CONVERTER *conv, int *saveErr, TQSL_ADIF_GET_FIE
 			strncpy(conv->rec.my_vucc_grids, resdata, sizeof conv->rec.my_vucc_grids);
 		} else if (!strcasecmp(result.name, "OPERATOR") && resdata) {
 			// Only use the OPERATOR field if it looks like a callsign
+			tqsl_strtoupper(resdata);
 			string op(resdata);
 			if (checkCallSign(op)) {
 				strncpy(conv->rec.my_operator, resdata, sizeof conv->rec.my_operator);
@@ -1222,6 +1225,7 @@ static void parse_adif_qso(TQSL_CONVERTER *conv, int *saveErr, TQSL_ADIF_GET_FIE
 #ifdef USE_OWNER_CALLSIGN
 		} else if (!strcasecmp(result.name, "OWNER_CALLSIGN") && resdata) {
 			// Only use the OWNER_CALLSIGN field if it looks like a callsign
+			tqsl_strtoupper(resdata);
 			string op(resdata);
 			if (checkCallSign(op)) {
 				strncpy(conv->rec.my_owner, resdata, sizeof conv->rec.my_owner);
@@ -1229,6 +1233,7 @@ static void parse_adif_qso(TQSL_CONVERTER *conv, int *saveErr, TQSL_ADIF_GET_FIE
 #endif
 		} else if (!strcasecmp(result.name, "STATION_CALLSIGN") && resdata) {
 			// Only use the STATION_CALLSIGN field if it looks like a callsign
+			tqsl_strtoupper(resdata);
 			string op(resdata);
 			if (checkCallSign(op)) {
 				strncpy(conv->rec.my_call, resdata, sizeof conv->rec.my_call);
@@ -1249,6 +1254,44 @@ static void parse_adif_qso(TQSL_CONVERTER *conv, int *saveErr, TQSL_ADIF_GET_FIE
 	return;
 }
 
+static int check_station(TQSL_CONVERTER *conv, const char *field, char *my, size_t len, const char *errfmt, bool update) {
+//
+// UPDATE is a boolean that when a change is made, that change
+// is propagated to the downstream values. STATE -> COUNTY and STATE->ZONES
+//
+	char val[256];
+	if (my[0] && !tqsl_getLocationField(conv->loc, field, val, sizeof val)) {
+		if (strcasecmp(my, val)) {
+			if (conv->location_handling == TQSL_LOC_UPDATE) {
+				int res = tqsl_setLocationField(conv->loc, field, my);
+				// -1 means trying to set a value that is not in the enumeration
+				if (res == -1) {
+					conv->rec_done = true;
+					snprintf(tQSL_CustomError, sizeof tQSL_CustomError, errfmt, my, val);
+					tQSL_Error = TQSL_LOCATION_MISMATCH | 0x1000;
+					return 1;
+				}
+				// -2 means that the label matched, so use that
+				if (res == -2) {
+					strncpy(my, tQSL_CustomError, len);
+				}
+				if (update) tqsl_updateStationLocationCapture(conv->loc);
+				conv->newstation = true;
+			} else if (strlen(val) > 0) {
+				conv->rec_done = true;
+				snprintf(tQSL_CustomError, sizeof tQSL_CustomError, errfmt, val, my);
+				tQSL_Error = TQSL_LOCATION_MISMATCH;
+				return 1;
+			} else {
+				tqsl_setLocationField(conv->loc, field, my);
+				if (update) tqsl_updateStationLocationCapture(conv->loc);
+				conv->newstation = true;
+			}
+		}
+	}
+	return 0;	// OK
+}
+
 DLLEXPORT const char* CALLCONVENTION
 tqsl_getConverterGABBI(tQSL_Converter convp) {
 	TQSL_CONVERTER *conv;
@@ -1371,6 +1414,7 @@ tqsl_getConverterGABBI(tQSL_Converter convp) {
 							saveErr = tQSL_Error;
 					} else if (!strcasecmp(field.name, "MYCALL")) {
 						strncpy(conv->rec.my_call, field.value, sizeof conv->rec.my_call);
+						tqsl_strtoupper(conv->rec.my_call);
 					}
 					if (conv->rec_text != "")
 						conv->rec_text += "\n";
@@ -1450,9 +1494,10 @@ tqsl_getConverterGABBI(tQSL_Converter convp) {
 	tqsl_strtoupper(conv->rec.rxband);
 	tqsl_strtoupper(conv->rec.mode);
 	tqsl_strtoupper(conv->rec.submode);
-	char val[256] = "";
-	// Try to find the GABBI mode several ways.
+	char val[256];
 	val[0] = '\0';
+
+	// Try to find the GABBI mode several ways.
 	if (conv->rec.submode[0] != '\0') {
 		char modeSub[256];
 		strncpy(modeSub, conv->rec.mode, sizeof modeSub);
@@ -1613,7 +1658,7 @@ tqsl_getConverterGABBI(tQSL_Converter convp) {
 		if (conv->rec.my_call[0]) {		// Update case handled above when switching certs
 			if (strcmp(conv->rec.my_call, conv->callsign)) {
 				conv->rec_done = true;
-				snprintf(tQSL_CustomError, sizeof tQSL_CustomError, "Callsign|%s|%s", conv->rec.my_call, conv->callsign);
+				snprintf(tQSL_CustomError, sizeof tQSL_CustomError, "Callsign|%s|%s", conv->callsign, conv->rec.my_call);
 				tQSL_Error = TQSL_CERT_MISMATCH;
 				return 0;
 			}
@@ -1638,31 +1683,37 @@ tqsl_getConverterGABBI(tQSL_Converter convp) {
 			}
 		}
 
-		bool newstation = false;
-
+		conv->newstation = false;
 		/*
 		 * Gridsquare handling - if the four-character grid matches the station loc
 		 * then don't complain; this is common for FT8/FT4 which have four char grids
 		 * and we don't want to reject every WSJT-X QSO just because the station
-		 * location has a higher precision grid.
+		 * location has a higher precision grid. Similarly, if the Station Location has
+		 * a six-character grid and the log has 8, then just compare 6 for report mode.
 		 */
 
 		tqsl_getLocationField(conv->loc, "GRIDSQUARE", val, sizeof val);
 		if (conv->rec.my_gridsquare[0] && !tqsl_getLocationField(conv->loc, "GRIDSQUARE", val, sizeof val)) {
 			bool okgrid;
+			unsigned int stnLen = strlen(val);
+			unsigned int logLen = strlen(conv->rec.my_gridsquare);
+			unsigned int compareLen = (stnLen < logLen ? stnLen : logLen);
+			if (strstr(val, ",") || strstr(conv->rec.my_gridsquare, ",")) {	// If it's a corner/edge
+				compareLen = 99;			// Compare all of it.
+			}
 			if (conv->location_handling == TQSL_LOC_UPDATE) {
 				okgrid = (strcasecmp(conv->rec.my_gridsquare, val) == 0);
 			} else {
-				okgrid = (strncasecmp(conv->rec.my_gridsquare, val, strlen(conv->rec.my_gridsquare)) == 0);
+				okgrid = (strncasecmp(conv->rec.my_gridsquare, val, compareLen) == 0);
 			}
 			if (!okgrid) {
 				if (conv->location_handling == TQSL_LOC_UPDATE) {
 					tqsl_setLocationField(conv->loc, "GRIDSQUARE", conv->rec.my_gridsquare);
-					newstation = true;
+					conv->newstation = true;
 				} else {
 					if (val[0] == '\0') {		// If station location has an empty grid
 						tqsl_setLocationField(conv->loc, "GRIDSQUARE", conv->rec.my_gridsquare);
-						newstation = true;
+						conv->newstation = true;
 					} else {
 						conv->rec_done = true;
 						snprintf(tQSL_CustomError, sizeof tQSL_CustomError, "Gridsquare|%s|%s", val, conv->rec.my_gridsquare);
@@ -1673,86 +1724,57 @@ tqsl_getConverterGABBI(tQSL_Converter convp) {
 			}
 		}
 
-// UPDATE below is a boolean that when a change is made, that change
-// is propagated to the downstream values. STATE -> COUNTY and STATE->ZONES
-//
-#define CHKSTN(FIELD, MY, ERRFMT, UPDATE) \
-		if (conv->rec.MY[0] && !tqsl_getLocationField(conv->loc, FIELD, val, sizeof val)) { \
-			if (strcasecmp(conv->rec.MY, val)) { \
-				if (conv->location_handling == TQSL_LOC_UPDATE) { \
-					/* -1 means trying to set a value that is not in the enumeration */ \
-					if (tqsl_setLocationField(conv->loc, FIELD, conv->rec.MY) == -1) {; \
-						conv->rec_done = true; \
-						snprintf(tQSL_CustomError, sizeof tQSL_CustomError, ERRFMT, conv->rec.MY, val); \
-						tQSL_Error = TQSL_LOCATION_MISMATCH | 0x1000; \
-						return 0; \
-					} \
-					if (UPDATE) tqsl_updateStationLocationCapture(conv->loc); \
-					newstation = true; \
-				} else if (strlen(val) > 0) { \
-					conv->rec_done = true; \
-					snprintf(tQSL_CustomError, sizeof tQSL_CustomError, ERRFMT, val, conv->rec.MY); \
-					tQSL_Error = TQSL_LOCATION_MISMATCH; \
-					return 0; \
-				} else { \
-					tqsl_setLocationField(conv->loc, FIELD, conv->rec.MY); \
-					if (UPDATE) tqsl_updateStationLocationCapture(conv->loc); \
-					newstation = true; \
-				} \
-			}  \
-		}
-
 		switch (conv->dxcc) {
 			case 6:		// Alaska
 			case 110:	// Hawaii
 			case 291:	// Cont US
-				CHKSTN("US_STATE", my_state, "US State|%s|%s", true)
-				CHKSTN("US_COUNTY", my_county, "US County|%s|%s", false)
+				if (check_station(conv, "US_STATE", conv->rec.my_state, sizeof conv->rec.my_state, "US State|%s|%s", true)) return 0;
+				if (check_station(conv, "US_COUNTY", conv->rec.my_county, sizeof conv->rec.my_county, "US County|%s|%s", false)) return 0;
 				break;
 			case 1:		// Canada
-				CHKSTN("CA_PROVINCE", my_state, "CA Province|%s|%s", true)
+				if (check_station(conv, "CA_PROVINCE", conv->rec.my_state, sizeof conv->rec.my_state, "CA Province|%s|%s", true)) return 0;
 				break;
 			case 15:	// Asiatic Russia
 			case 54:	// European Russia
 			case 61:	// FJL
 			case 125:	// Juan Fernandez
 			case 151:	// Malyj Vysotskij
-				CHKSTN("RU_OBLAST", my_state, "RU Oblast|%s|%s", true)
+				if (check_station(conv, "RU_OBLAST", conv->rec.my_state, sizeof conv->rec.my_state, "RU Oblast|%s|%s", true)) return 0;
 				break;
 			case 318:	// China
-				CHKSTN("CN_PROVINCE", my_state, "CN Province|%s|%s", true)
+				if (check_station(conv, "CN_PROVINCE", conv->rec.my_state, sizeof conv->rec.my_state, "CN Province|%s|%s", true)) return 0;
 				break;
 			case 150:	// Australia
-				CHKSTN("AU_STATE", my_state, "AU State|%s|%s", true)
+				if (check_station(conv, "AU_STATE", conv->rec.my_state, sizeof conv->rec.my_state, "AU State|%s|%s", true)) return 0;
 				break;
 			case 339:	// Japan
-				CHKSTN("JA_PREFECTURE", my_state, "JA Prefecture|%s|%s", true)
-				CHKSTN("JA_CITY_GUN_KU", my_county, "JA City/Gun/Ku|%s|%s", false)
+				if (check_station(conv, "JA_PREFECTURE", conv->rec.my_state, sizeof conv->rec.my_state, "JA Prefecture|%s|%s", true)) return 0;
+				if (check_station(conv, "JA_CITY_GUN_KU", conv->rec.my_county, sizeof conv->rec.my_county, "JA City/Gun/Ku|%s|%s", false)) return 0;
 				break;
 			case 5:		// Finland
-				CHKSTN("FI_KUNTA", my_state, "FI Kunta|%s|%s", true)
+				if (check_station(conv, "FI_KUNTA", conv->rec.my_state, sizeof conv->rec.my_state, "FI Kunta|%s|%s", true)) return 0;
 				break;
 		}
 
-		CHKSTN("ITUZ", my_itu_zone, "ITU Zone|%s|%s", false)
-		CHKSTN("CQZ", my_cq_zone, "CQ Zone|%s|%s", false)
-		CHKSTN("IOTA", my_iota, "IOTA|%s|%s", false)
+		if (check_station(conv, "ITUZ", conv->rec.my_itu_zone, sizeof conv->rec.my_itu_zone, "ITU Zone|%s|%s", false)) return 0;
+		if (check_station(conv, "CQZ", conv->rec.my_cq_zone, sizeof conv->rec.my_cq_zone, "CQ Zone|%s|%s", false)) return 0;
+		if (check_station(conv, "IOTA", conv->rec.my_iota, sizeof conv->rec.my_iota, "IOTA|%s|%s", false)) return 0;
 
 		if (conv->rec.my_cnty_state[0] != '\0') {
 			char locstate[5];
 			tqsl_getLocationField(conv->loc, "US_STATE", locstate, sizeof locstate);
-			if (strcmp(conv->rec.my_cnty_state, locstate)) {		// County does not match state
-				conv->rec_done = true; 
-				snprintf(tQSL_CustomError, sizeof tQSL_CustomError, "US County State|%s|%s", conv->rec.my_cnty_state, locstate); 
-				tQSL_Error = TQSL_LOCATION_MISMATCH | 0x1000; 
-				return 0; 
+			if (strcasecmp(conv->rec.my_cnty_state, locstate)) {		// County does not match state
+				conv->rec_done = true;
+				snprintf(tQSL_CustomError, sizeof tQSL_CustomError, "US County State|%s|%s", conv->rec.my_cnty_state, locstate);
+				tQSL_Error = TQSL_LOCATION_MISMATCH | 0x1000;
+				return 0;
 			}
 		}
-		if (newstation) {
+		if (conv->newstation) {
+			conv->newstation = false;
 			conv->loc_uid++;
 			return get_station_rec(conv);
 		}
-#undef CHKSTN
 	}	// if ignoring MY_ fields
 
 	if (conv->need_station_rec) {
